=======
Credits
=======

Development Lead
----------------

* Pepijn Kenter <titusjan@gmail.com>


Contributors
------------

* Christoph Buchner (https://github.com/bilderbuchi)
* Thomas Grainger (https://github.com/graingert)
* Lui Habl (https://github.com/luihabl): Exdir Plugin
* Sidney Cadot (https://github.com/sidneycadot/json_with_comments): JSON with comments module.
